@@ -99,12 +99,14 @@ struct JwtPayload {
     sub: SpiffeID,
 }
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Serialize, Deserialize, Debug)]
 struct Claims {
     aud: Vec<String>,
     exp: usize,
-    iat: usize,
-    iss: String,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    iat: Option<usize>,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    iss: Option<String>,
     sub: String,
 }
 
@@ -186,18 +188,6 @@ mod tests {
     use jsonwebtoken::{encode, EncodingKey, Header};
     use serde_test::{assert_tokens, Token};
 
-    impl Default for Claims {
-        fn default() -> Self {
-            Claims {
-                aud: vec![String::from("dummy_audience")],
-                exp: 1753717118, // Mon Jul 28 2025 15:38:38 GMT+0000
-                iat: 1627015222, // Fri Jul 23 2021 04:40:22 GMT+0000
-                iss: String::from("user"),
-                sub: String::from("spiffe://dummy.org/ns:dummy/id:dummy"),
-            }
-        }
-    }
-
     impl Default for JwtKey {
         fn default() -> Self {
             JwtKey {
@@ -224,18 +214,34 @@ mod tests {
         }
     }
 
+    impl Default for Claims {
+        fn default() -> Self {
+            Claims {
+                aud: vec![String::from("dummy_audience")],
+                exp: 1753717118, // Mon Jul 28 2025 15:38:38 GMT+0000
+                iat: None,
+                iss: None,
+                sub: String::from("spiffe://dummy.org/ns:dummy/id:dummy"),
+            }
+        }
+    }
+
     struct Setup {
         bundle_p256: JwtBundle,
         bundle_p384: JwtBundle,
         bundle_invalid_curve: JwtBundle,
+        bundle_reserved_slot: JwtBundle,
         token_p256: String,
         token_p384: String,
+        token_reserved_slot: String,
         token_wrong_sig: &'static str,
         token_invalid_segment_length: &'static str,
         token_invalid_header_type: String,
         token_invalid_key_id: String,
         token_expired: String,
         token_about_to_expire: String,
+        token_with_issuer: String,
+        token_with_iat: String,
     }
 
     impl Setup {
@@ -270,12 +276,37 @@ mod tests {
                         inner: bundle_inner,
                     }
                 },
+                // this slot is used to accept public key and test manually, signature verification is doomed to be failed 
+                // because we cannot have private key which signs the token.
+                bundle_reserved_slot: {
+                    let jwt_key = JwtKey {
+                        key_type: String::from("JWT"),
+                        // change key_id here for manual verification
+                        key_id: String::from("dummy_keyid"),
+                        curve: String::from("P-256"),
+                        // use python3 gen_x_y_from_pubkey_string.py to generate p256 public key and replace x, y here 
+                        // for manual verification
+                        x: String::from("ovsRfW7L2V8zyGyJkOLA_JlczbgssQ7JrVQ2pzS74QY"),
+                        y: String::from("kO_n1Pz9qbK8gNzfXA4Hfo1K11-Dyl1JilDFYltNyhw"),
+                    };
+                    let mut bundle_inner = BTreeMap::new();
+                    // change key_id here for manual verification
+                    bundle_inner.insert(String::from("dummy_keyid"), jwt_key);
+                    JwtBundle{
+                        inner: bundle_inner,
+                    }
+                },
                 token_p256: {
                     generate_token_on_algorithm(Algorithm::ES256)
                 },
                 token_p384: {
                     generate_token_on_algorithm(Algorithm::ES384)
                 },
+                token_reserved_slot: {
+                    // change this to token to be verified manually.
+                    // "eyJ0eXAiOiJKV1QiLCJhbGciOiJFUzI1NiIsImtpZCI6ImR1bW15X2tleWlkIn0.eyJhdWQiOlsiZHVtbXlfYXVkaWVuY2UiXSwiZXhwIjoxNzUzNzE3MTE4LCJzdWIiOiJzcGlmZmU6Ly9kdW1teS5vcmcvbnM6ZHVtbXkvaWQ6ZHVtbXkifQ.Js21h6fppSJ4MUjrbk3pvIrJ_ybLD0UvZcA9lldXnaxVEbiB3NBfcOPAaKHaQJN_BYQZiERRyFrUMRprx-MvTQ"
+                    String::from("eyJ0eXAiOiJKV1QiLCJhbGciOiJFUzI1NiIsImtpZCI6ImR1bW15X2tleWlkIn0.eyJhdWQiOlsiZHVtbXlfYXVkaWVuY2UiXSwiZXhwIjoxNzUzNzE3MTE4LCJzdWIiOiJzcGlmZmU6Ly9kdW1teS5vcmcvbnM6ZHVtbXkvaWQ6ZHVtbXkifQ.Js21h6fppSJ4MUjrbk3pvIrJ_ybLD0UvZcA9lldXnaxVEbiB3NBfcOPAaKHaQJN_BYQZiERRyFrUMRprx-MvTA")
+                },
                 token_wrong_sig: "eyJ0eXAiOiJKV1QiLCJhbGciOiJFUzI1NiIsImtpZCI6ImR1bW15X2tleWlkIn0.eyJhdWQiOlsiZHVtbXlfYXVkaWVuY2UiXSwiZXhwIjoxNzUzNzE3MTE4LCJpYXQiOjE2MjcwMTUyMjIsImlzcyI6InVzZXIiLCJzdWIiOiJzcGlmZmU6Ly9kdW1teS5vcmcvbnM6ZHVtbXkvaWQ6ZHVtbXkifQ.q7RMpz74PigIib2x34bSU6mp72Bw26tTS9Zl3nV_Gwzpt7-RsQFktbKefZC9JV0uJptCKJNLeyXBdNs3NgV7GA",
                 token_invalid_segment_length: "eyJ0eXAiOiJKV1QiLCJhbGciOiJFUzI1NiIsImtpZCI6ImR1bW15X2tleWlkIn0",
                 token_invalid_header_type: {
@@ -296,6 +327,12 @@ mod tests {
                     let expired_time = now.as_secs() as usize - 46460;
                     generate_token_on_expire(expired_time)
                 },
+                token_with_issuer: {
+                    generate_token_with_issuer()
+                },
+                token_with_iat: {
+                    generate_token_with_iat()
+                }
             }
         }
     }
@@ -394,6 +431,52 @@ mod tests {
         .unwrap()
     }
 
+    fn generate_token_with_issuer() -> String {
+        let priv_key_pem = include_bytes!("../tests/data/priv_key_256v1.pem");
+
+        let my_claims = Claims {
+            iss: Some(String::from("user")),
+            ..Claims::default()
+        };
+        let header = Header {
+            alg: Algorithm::ES256,
+            kid: Some("dummy_keyid".to_owned()),
+            ..Header::default()
+        };
+
+        let key = openssl::pkey::PKey::private_key_from_pem(priv_key_pem).unwrap();
+        let pem = key.private_key_to_pem_pkcs8().unwrap();
+        encode(
+            &header,
+            &my_claims,
+            &EncodingKey::from_ec_pem(pem.as_slice()).unwrap(),
+        )
+        .unwrap()
+    }
+
+    fn generate_token_with_iat() -> String {
+        let priv_key_pem = include_bytes!("../tests/data/priv_key_256v1.pem");
+
+        let my_claims = Claims {
+            iat: Some(1627015222), // Fri Jul 23 2021 04:40:22 GMT+0000
+            ..Claims::default()
+        };
+        let header = Header {
+            alg: Algorithm::ES256,
+            kid: Some("dummy_keyid".to_owned()),
+            ..Header::default()
+        };
+
+        let key = openssl::pkey::PKey::private_key_from_pem(priv_key_pem).unwrap();
+        let pem = key.private_key_to_pem_pkcs8().unwrap();
+        encode(
+            &header,
+            &my_claims,
+            &EncodingKey::from_ec_pem(pem.as_slice()).unwrap(),
+        )
+        .unwrap()
+    }
+
     #[test]
     fn test_verify_token_p256() {
         let setup = Setup::new();
@@ -418,6 +501,21 @@ mod tests {
         );
     }
 
+    #[test]
+    fn test_verify_token_reserved_slot() {
+        let setup = Setup::new();
+        assert_eq!(
+            format!(
+                "{:#}",
+                setup
+                    .bundle_reserved_slot
+                    .verify_token::<JwtPayload>(&setup.token_reserved_slot)
+                    .unwrap_err()
+            ),
+            "Error(InvalidSignature) happened during decoding Jwt token"
+        );
+    }
+
     #[test]
     fn test_verify_token_wrong_sig() {
         let setup = Setup::new();
@@ -520,6 +618,30 @@ mod tests {
         );
     }
 
+    #[test]
+    fn test_verify_token_with_issuer() {
+        let setup = Setup::new();
+        assert!(
+            setup
+                .bundle_p256
+                .verify_token::<JwtPayload>(&setup.token_with_issuer)
+                .is_ok(),
+            "Token with issuer verification failed"
+        );
+    }
+
+    #[test]
+    fn test_verify_token_with_iat() {
+        let setup = Setup::new();
+        assert!(
+            setup
+                .bundle_p256
+                .verify_token::<JwtPayload>(&setup.token_with_iat)
+                .is_ok(),
+            "Token with iat verification failed"
+        );
+    }
+
     #[test]
     fn test_verify_spiffe_id_p256() {
         let setup = Setup::new();
